#!/usr/bin/env ruby


begin
require 'Qt'
rescue LoadError
	error = 'QtRuby (Qt bindings for ruby) is required for this script.'
	puts error
	`kdialog --sorry "#{error}"`
	exit
end

require "#{File.dirname( File.expand_path(__FILE__))}/amarok.rb"

# set the configuration by editing these constants

RATINGS_LABELS = {
1 => '',
2 => 'Awful',
3 => 'Barely tolerable',
4 => 'Tolerable',
5 => 'Okay',
6 => 'Good',
7 => 'Very good',
8 => 'Excellent',
9 => 'Amazing',
10 => 'Favourite',
}

# RATINGS_LABELS = {
# 1 => '',
# 2 => 'crap',
# 3 => '+',
# 4 => '-',
# 5 => 'avarage',
# 6 => '+',
# 7 => '-',
# 8 => 'excellent',
# 9 => '+',
# 10 => 'impossible',
# }

# setting value to nil will disable auto hiding
# TIMEOUT_AFTER = nil
TIMEOUT_AFTER = 9000 #ms

# (0 , 0) is at the top left corner of screen
XPOS = 0
YPOS = 0

# the pop up will show when one of these rates is assigned to the target track (0 for unrated tracks)
# TARGET_RATES =  [0 , 6 ]
TARGET_RATES = [0]


class RatePopup < Qt::Widget

slots "set_rating(int)"
def initialize(*k)
super(*k)
@target = nil
@hide_timer = Qt::Timer.new
createPopup
def_popup_methods
connect(@popup , SIGNAL("activated(int)") , self , SLOT("set_rating(int)"))
connect(@hide_timer , SIGNAL("timeout()") , @popup , SLOT("hide()"))
end



def createPopup
@popup = Qt::PopupMenu.new
(2..10).each do |r|
id = @popup.insertItem(RATINGS_LABELS[r],self , SLOT("set_rating(int)"))
@popup.setItemParameter( id, r )
end
end


def def_popup_methods

def @popup.keyPressEvent(e)
if %w|2 3 4 5 6 7 8 9 0|.include? e.text
emit activated(e.text.to_i)
hide
else
super
end

end

end

def set_rating(int)
# rating = int
# rating = 10 if rating == 0
rating = (int == 0) ? 10 : int
`dcop amarok player setRatingByPath "#{@target}" #{rating}` 

end

def jump_in(url)
@target = url
@popup.popup(Qt::Point.new(XPOS , YPOS))
@hide_timer.start(TIMEOUT_AFTER , true) if TIMEOUT_AFTER
end

end

class RateItKid < AmaroKSlots

def initialize
update_current
end

# def stateChange_playing
# update_current
# end

def trackChange
$stderr.print @current_url , ' , ' , @current_id , "\n"
return if @current_url.empty?
# current_rating = `dcop amarok collection query "select rating from statistics where url = \\"#{@current_url}\\""`.to_i
current_rating = `dcop amarok collection query "select rating from statistics where uniqueid = \\"#{@current_id}\\""`.to_i

if TARGET_RATES.include? current_rating
$popup.jump_in(@current_url)
end
ensure
update_current
end

# alias_method :stateChange_idle, :trackChange

def configure
msg = "settings can be changed in the script file"
`kdialog  --msgbox "#{msg}"`
end

def update_current
@current_id = `dcop amarok playlist currentTrackUniqueId`.chomp
@current_url = `dcop amarok player path`.chomp
end

end


app = Qt::Application.new ARGV
$popup = RatePopup.new
r=RateItKid.new()
amaroKCommunication = AmaroKLib.new(app, r )
app.exec
